The hail scripts in this repo can be used to pre-process variant callsets and export them to elasticsearch. 

See [hail_elasticsearch_pipelines/luigi_pipeline/README.md](luigi_pipeline/README.md) for details.
